{*******************************************************}
{File:      NCOciBuff.PAS                               }
{Revision:  0.02.01 / 29.10.1999                        }
{Comment:   NC OCI8 VCL: registration unit              }
{Copyright: (c) 1999, Nica-Com Ltd.                     }
{Author:    Dmitry Arefiev, diman@ncom.ru               }
{*******************************************************}
{$I NCOciDef.inc}

unit NCOciReg;

interface

    procedure Register;

implementation

{$R NCO8.DCR}

Uses Classes, NCOciDB, DsgnIntf, NCTimer;

{ --------------------------------------------------------------------------- }
{ --------------------------------------------------------------------------- }

Type
    TOCIListProperty = class(TStringProperty)
        FObjKind: TOCIObjKind;
        FParentObj: String;
        function GetAttributes: TPropertyAttributes; override;
        procedure GetValues(Proc: TGetStrProc); override;
    end;

    TOCIServerNameProperty = class(TOCIListProperty)
        procedure GetValues(Proc: TGetStrProc); override;
    end;

    TOCIDatabaseNameProperty = class(TOCIListProperty)
        procedure GetValues(Proc: TGetStrProc); override;
    end;

    TOCIStoredProcNameProperty = class(TOCIListProperty)
        procedure GetValues(Proc: TGetStrProc); override;
    end;

    TOCIOPackageNameProperty = class(TOCIListProperty)
        procedure GetValues(Proc: TGetStrProc); override;
    end;

    TOCIOProcedureNameProperty = class(TOCIListProperty)
        procedure GetValues(Proc: TGetStrProc); override;
    end;

{ --------------------------------------------------------------------------- }
{ --------------------------------------------------------------------------- }

function TOCIListProperty.GetAttributes: TPropertyAttributes;
begin
    Result := [paValueList, paSortList, paMultiSelect];
end;

procedure TOCIListProperty.GetValues(Proc: TGetStrProc);
var
    List: TStringList;
    i: Integer;
    db: TOCIDatabase;
    comp: TPersistent;
begin
    List := TStringList.Create;
    try
        comp := GetComponent(0);
        db := nil;
        if not (FObjKind in [okService, okDatabase]) then
            if comp is TOCIDatabase then
                db := TOCIDatabase(db)
            else if comp is TOCIDataSet then
                db := TOCIDatabase.DatabaseByName(TOCIDataSet(comp).DatabaseName);
        TOCIDatabase.GetObjectsList(db, List, FParentObj, FObjKind, True);
        for i := 0 to List.Count - 1 do
            Proc(List[i]);
    finally
        List.Free;
    end;
end;

procedure TOCIServerNameProperty.GetValues(Proc: TGetStrProc);
begin
    FObjKind := okService;
    FParentObj := '';
    inherited GetValues(Proc);
end;

procedure TOCIDatabaseNameProperty.GetValues(Proc: TGetStrProc);
begin
    FObjKind := okDatabase;
    FParentObj := '';
    inherited GetValues(Proc);
end;

procedure TOCIStoredProcNameProperty.GetValues(Proc: TGetStrProc);
begin
    FObjKind := okProc;
    FParentObj := '';
    inherited GetValues(Proc);
end;

procedure TOCIOPackageNameProperty.GetValues(Proc: TGetStrProc);
begin
    FObjKind := okPackage;
    FParentObj := '';
    inherited GetValues(Proc);
end;

procedure TOCIOProcedureNameProperty.GetValues(Proc: TGetStrProc);
begin
    FObjKind := okProc;
    FParentObj := (GetComponent(0) as TOCIStoredProc).OPackageName;
    inherited GetValues(Proc);
end;

procedure Register;
begin
    RegisterPropertyEditor(TypeInfo(String), TOCIDatabase, 'ServerName', TOCIServerNameProperty);
    RegisterPropertyEditor(TypeInfo(String), TOCIDataSet, 'DatabaseName', TOCIDatabaseNameProperty);
    RegisterPropertyEditor(TypeInfo(String), TOCIStoredProc, 'StoredProcName', TOCIStoredProcNameProperty);
    RegisterPropertyEditor(TypeInfo(String), TOCIStoredProc, 'OPackageName', TOCIOPackageNameProperty);
    RegisterPropertyEditor(TypeInfo(String), TOCIStoredProc, 'OProcedureName', TOCIOProcedureNameProperty);
    RegisterComponents('NC OCI8', [TOCIDatabase, TOCIQuery, TOCIStoredProc, TNCTimer]);
end;

end.
